pub struct Mbuf { /* private fields */ }Expand description
A packet buffer.
This is a wrapper around a DPDK message buffer that represents a single Ethernet frame.
Implementations
Sourceimpl Mbuf
impl Mbuf
pub fn new_ref(mbuf: &Mbuf) -> Mbuf
Sourcepub fn get_data_slice(&self, offset: usize, count: usize) -> Result<&[u8]>
pub fn get_data_slice(&self, offset: usize, count: usize) -> Result<&[u8]>
Returns a byte slice of data with length count at offset.
Errors if offset is greater than or equal to the buffer length or count exceeds the size
of the data stored at offset.
pub fn has_mark(&mut self, _mark: u32) -> bool